@@ -29,10 +29,12 @@ import getpass
 import tempfile
 import time
 import base64
+from functools import wraps
 
-VERSION = '1.26'
+VERSION = '1.29'
 
 def login_required(func):
+    @wraps(func)
     def decorator(self, *args, **kwargs):
         if not self._authenticated:
             self.authenticate()
@@ -40,6 +42,7 @@ def login_required(func):
     return decorator
 
 def app_id_required(func):
+    @wraps(func)
     def decorator(self, *args, **kwargs):
         if len(args) == 0 and 'app_id' not in kwargs:
             raise MetroClientError('You must specify an application global ID')
@@ -78,7 +81,9 @@ class MetroClient(object):
         self.__manage_url = '{0}/manage'.format(self.__api_url)
         self.__version = VERSION
         self._authenticated = False
-        self._http = httplib2.Http()
+        ca_certs = os.path.join(os.path.dirname(__file__), 'cacerts.txt')
+        self._http = httplib2.Http(ca_certs=ca_certs)
+        # add startssl ca
         self._headers = {
             'User-Agent': 'metroclient/{0}'.format(VERSION),
             'Content-type': 'application/json',
@@ -91,10 +96,14 @@ class MetroClient(object):
                 raise MetroClientError('You must specify a url')
             resp = None
             cont = None
-            if body:
-                resp, cont = self._http.request(url, method, headers=self._headers, body=body)
-            else:
-                resp, cont = self._http.request(url, method, headers=self._headers)
+            try:
+                if body:
+                    resp, cont = self._http.request(url, method, headers=self._headers, body=body)
+                else:
+                    resp, cont = self._http.request(url, method, headers=self._headers)
+            except:
+                import traceback
+                traceback.print_exc()
             return resp, cont
         except Exception, d:
             raise MetroClientError(d)
@@ -148,6 +157,30 @@ class MetroClient(object):
         else:
             raise MetroClientError('Error checking for updates')
 
+    def create_config(self, app_dir=None, config_version='', app_name='', app_version='', \
+        app_description='', app_modules='', wsgi_module='', paste_config='', app_fixtures='', \
+        load_data=False, use_ssl=True, force_ssl=False, deploy_type='normal', wsgi_env_vars=''):
+        # write config
+        f = open('%s/metro.config' % (app_dir), 'w')
+        f.write('config_version:: %s\n' % (config_version))
+        f.write('name:: %s\n' % (app_name))
+        f.write('version:: %s\n' % (app_version))
+        f.write('description:: %s\n' % (app_description))
+        f.write('modules:: %s\n' % (app_modules))
+        f.write('wsgi_module:: %s\n' % (wsgi_module))
+        f.write('wsgi_env_vars:: %s\n' % (wsgi_env_vars))
+        f.write('paste_config:: %s\n' % (paste_config))
+        f.write('fixtures:: %s\n' % (app_fixtures))
+        # load data
+        f.write('load_data:: %s\n' % (str(load_data).lower()))
+        # ssl
+        f.write('use_ssl:: %s\n' % (str(use_ssl).lower()))
+        # force ssl
+        f.write('force_ssl:: %s\n' % (str(force_ssl).lower()))
+        # quick deploy
+        f.write('deploy_type:: %s\n' % (deploy_type.lower()))
+        f.close()
+
     def create_package(self, filename=None, path=None):
         '''Creates a package to be used for deployment'''
         try:
